==> owncloud-9.1.4.tgz: owncloud/apps/files_sharing/l10n/de_DE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Not allowed to create a federated share with the same user server" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Couldn't add remote share" : "Entfernte Freigabe kann nicht hinzugefügt werden",
    "Shared with you" : "Mit Ihnen geteilt",
    "Shared with others" : "Von Ihnen geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Ihnen geteilt",
    "Files and folders others share with you will show up here" : "Mit Ihnen geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Dateien und Ordner, die Sie teilen, werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Dateien und Ordner, die Sie per Link teilen, werden hier erscheinen",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die entfernte Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "You can upload into this folder" : "Sie können in diesen Ordner hochladen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine OwnCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige OwnCloud-Adresse",
    "Shared by" : "Geteilt von",
    "Sharing" : "Teilen",
    "Share API is disabled" : "Teilen-API ist deaktivert",
    "Wrong share ID, share doesn't exist" : "Fehlerhafte Freigabe-ID, Freigabe existiert nicht",
    "Could not delete share" : "Freigabe konnte nicht gelöscht werden",
    "Please specify a file or folder path" : "Bitte eine Datei oder  Verzeichnis definieren",
    "Wrong path, file/folder doesn't exist" : "Falscher Pfad, Datei/Verzeichnis existiert nicht",
    "Please specify a valid user" : "Bitte geben Sie einen gültigen Nutzer an",
    "Group sharing is disabled by the administrator" : "Die Gruppenfreigabe ist durch den Administrator deaktiviert",
    "Please specify a valid group" : "Bitte geben Sie eine gültige Gruppe an",
    "Public link sharing is disabled by the administrator" : "Die öffentliche Freigabe von Links ist durch den Administrator deaktiviert",
    "Public upload disabled by the administrator" : "Das öffentliche Hochladen ist durch den Administrator deaktiviert",
    "Public upload is only possible for publicly shared folders" : "Das öffentliche Hochladen ist nur für öffentlich freigegebene Ordner erlaubt",
    "Invalid date, date format must be YYYY-MM-DD" : "Ungültiges Datum, das Datumsformat muss JJJJ-MM-TT sein",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %s nicht erlaubt.",
    "Unknown share type" : "Unbekannter Freigabetyp",
    "Not a directory" : "Kein Verzeichnis",
    "Could not lock path" : "Pfad konnte nicht gesperrt werden",
    "Can't change permissions for public share links" : "Berechtigungen für öffentlich freigegebene Links konnten nicht geändert werden",
    "Wrong or no update parameter given" : "Falscher oder kein Updateparameter wurde übergeben",
    "Cannot increase permissions" : "Berechtigungen können nicht erhöht werden",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
    "You received a new remote share %2$s from %1$s" : "Sie haben eine neue Remotefreigabe %2$s von %1$s erhalten",
    "You received a new remote share from %s" : "Sie haben eine neue Remotefreigabe von %s erhalten",
    "%1$s accepted remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s akzeptiert",
    "%1$s declined remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s abgelehnt",
    "%1$s unshared %2$s from you" : "%1$s hat die Freigabe von %2$s für Sie entfernt",
    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
    "You shared %1$s with %2$s" : "Sie haben %1$s mit %2$s geteilt",
    "%2$s shared %1$s with %3$s" : "%2$s hat %1$s mit %3$s geteilt",
    "You removed the share of %2$s for %1$s" : "Sie haben die Freigabe von %2$s für %1$s entfernt",
    "%2$s removed the share of %3$s for %1$s" : "%2$s hat die Freigabe von %3$s für %1$s entfernt",
    "You shared %1$s with group %2$s" : "Sie haben %1$s mit der Gruppe %2$s geteilt",
    "%2$s shared %1$s with group %3$s" : "%2$s hat %1$s mit der Gruppe %3$s geteilt",
    "You removed the share of group %2$s for %1$s" : "Sie haben die Freigabe der Gruppe %2$s für %1$s entfernt",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s hat die Freigabe der Gruppe %3$s für %1$s entfernt",
    "%2$s shared %1$s via link" : "%2$s hat %1$s über einen Link geteilt",
    "You shared %1$s via link" : "Sie haben %1$s über einen Link geteilt",
    "You removed the public link for %1$s" : "Sie haben die Freigabe als Link für %1$s entfernt",
    "%2$s removed the public link for %1$s" : "%2$s hat die Freigabe als Link für %1$s entfernt",
    "Your public link for %1$s expired" : "Ihre Freigabe als Link für %1$s ist abgelaufen",
    "The public link of %2$s for %1$s expired" : "Die Freigabe als Link von %2$s für %1$s ist abgelaufen",
    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Ihnen geteilt",
    "%2$s removed the share for %1$s" : "%2$s hat die Freigabe für %1$s entfernt",
    "Downloaded via public link" : "Über den öffentlichen Link heruntergeladen",
    "Shared with %2$s" : "Geteilt mit %2$s",
    "Shared with %3$s by %2$s" : "Geteilt mit %3$s von %2$s",
    "Removed share for %2$s" : "Freigabe für %2$s entfernt",
    "%2$s removed share for %3$s" : "%2$s hat die Freigabe für %3$s entfernt",
    "Shared with group %2$s" : "Geteilt mit der Gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Geteilt mit der Gruppe %3$s von %2$s",
    "Removed share of group %2$s" : "Freigabe für Gruppe %2$s entfernt",
    "%2$s removed share of group %3$s" : "%2$s hat die Freigabe für Gruppe %3$s entfernt",
    "Shared via link by %2$s" : "Geteilt durch einen Link von %2$s",
    "Shared via public link" : "Durch einen öffentlichen Link geteilt",
    "Removed public link" : "Öffentlichen Link entfernt",
    "%2$s removed public link" : "%2$s hat die Freigabe als Link entfernt",
    "Public link expired" : "öffentlicher Link ist abgelaufen",
    "Public link of %2$s expired" : "Öffentlicher Link von %2$s ist abgelaufen",
    "Shared by %2$s" : "Geteilt von %2$s",
    "Shares" : "Geteiltes",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Freigabezeitpunkt",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "Add to your ownCloud" : "Zu Ihrer ownCloud hinzufügen",
    "Download" : "Herunterladen",
    "Download %s" : "Download %s",
    "Direct link" : "Direkte Verlinkung"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/de_DE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Not allowed to create a federated share with the same user server" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer ist nicht erlaubt",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Couldn't add remote share" : "Entfernte Freigabe konnte nicht hinzugefügt werden",
    "Shared with you" : "Mit Ihnen geteilt",
    "Shared with others" : "Mit anderen geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Anonymous upload" : "Anonymes hochladen",
    "Click to select files or use drag & drop to upload" : "Dateien auswählen oder Datei zum Hochladen hereinziehen",
    "Uploaded files" : "Hochgeladene Dateien",
    "Uploading..." : "Hochladen…",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Ihnen geteilt",
    "Files and folders others share with you will show up here" : "Mit Ihnen geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Dateien und Ordner, die Sie teilen, werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Dateien und Ordner, die Sie per Link teilen, werden hier erscheinen",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die entfernte Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "You can upload into this folder" : "Sie können in diesen Ordner hochladen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine OwnCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige OwnCloud-Adresse",
    "Share" : "Teilen",
    "No expiration date set" : "Kein Ablaufdatum angegeben",
    "Shared by" : "Geteilt von",
    "Sharing" : "Teilen",
    "Share API is disabled" : "Teilen-API ist deaktivert",
    "Wrong share ID, share doesn't exist" : "Fehlerhafte Freigabe-ID, Freigabe existiert nicht",
    "Could not delete share" : "Freigabe konnte nicht gelöscht werden",
    "Please specify a file or folder path" : "Bitte eine Datei oder  Verzeichnis definieren",
    "Wrong path, file/folder doesn't exist" : "Falscher Pfad, Datei/Verzeichnis existiert nicht",
    "Cannot remove all permissions" : "Alle Berechtigungen konnten nicht entfernt werden",
    "Please specify a valid user" : "Bitte geben Sie einen gültigen Nutzer an",
    "Group sharing is disabled by the administrator" : "Die Gruppenfreigabe ist durch den Administrator deaktiviert",
    "Please specify a valid group" : "Bitte geben Sie eine gültige Gruppe an",
    "Public link sharing is disabled by the administrator" : "Die öffentliche Freigabe von Links ist durch den Administrator deaktiviert",
    "Public upload disabled by the administrator" : "Das öffentliche Hochladen ist durch den Administrator deaktiviert",
    "Public upload is only possible for publicly shared folders" : "Das öffentliche Hochladen ist nur für öffentlich freigegebene Ordner erlaubt",
    "Invalid date, date format must be YYYY-MM-DD" : "Ungültiges Datum, das Datumsformat muss JJJJ-MM-TT sein",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %s nicht erlaubt.",
    "Unknown share type" : "Unbekannter Freigabetyp",
    "Not a directory" : "Kein Verzeichnis",
    "Could not lock path" : "Pfad konnte nicht gesperrt werden",
    "Can't change permissions for public share links" : "Berechtigungen für öffentlich freigegebene Links konnten nicht geändert werden",
    "Wrong or no update parameter given" : "Falscher oder kein Updateparameter wurde übergeben",
    "Cannot increase permissions" : "Berechtigungen können nicht erhöht werden",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
    "You received a new remote share %2$s from %1$s" : "Sie haben eine neue Remotefreigabe %2$s von %1$s erhalten",
    "You received a new remote share from %s" : "Sie haben eine neue Remotefreigabe von %s erhalten",
    "%1$s accepted remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s akzeptiert",
    "%1$s declined remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s abgelehnt",
    "%1$s unshared %2$s from you" : "%1$s hat die Freigabe von %2$s für Sie entfernt",
    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
    "You shared %1$s with %2$s" : "Sie haben %1$s mit %2$s geteilt",
    "%2$s shared %1$s with %3$s" : "%2$s hat %1$s mit %3$s geteilt",
    "You removed the share of %2$s for %1$s" : "Sie haben die Freigabe von %2$s für %1$s entfernt",
    "%2$s removed the share of %3$s for %1$s" : "%2$s hat die Freigabe von %3$s für %1$s entfernt",
    "You shared %1$s with group %2$s" : "Sie haben %1$s mit der Gruppe %2$s geteilt",
    "%2$s shared %1$s with group %3$s" : "%2$s hat %1$s mit der Gruppe %3$s geteilt",
    "You removed the share of group %2$s for %1$s" : "Sie haben die Freigabe der Gruppe %2$s für %1$s entfernt",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s hat die Freigabe der Gruppe %3$s für %1$s entfernt",
    "%2$s shared %1$s via link" : "%2$s hat %1$s über einen Link geteilt",
    "You shared %1$s via link" : "Sie haben %1$s über einen Link geteilt",
    "You removed the public link for %1$s" : "Sie haben die Freigabe als Link für %1$s entfernt",
    "%2$s removed the public link for %1$s" : "%2$s hat die Freigabe als Link für %1$s entfernt",
    "Your public link for %1$s expired" : "Ihre Freigabe als Link für %1$s ist abgelaufen",
    "The public link of %2$s for %1$s expired" : "Die Freigabe als Link von %2$s für %1$s ist abgelaufen",
    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Ihnen geteilt",
    "%2$s removed the share for %1$s" : "%2$s hat die Freigabe für %1$s entfernt",
    "Downloaded via public link" : "Über den öffentlichen Link heruntergeladen",
    "Shared with %2$s" : "Geteilt mit %2$s",
    "Shared with %3$s by %2$s" : "Geteilt mit %3$s von %2$s",
    "Removed share for %2$s" : "Freigabe für %2$s entfernt",
    "%2$s removed share for %3$s" : "%2$s hat die Freigabe für %3$s entfernt",
    "Shared with group %2$s" : "Geteilt mit der Gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Geteilt mit der Gruppe %3$s von %2$s",
    "Removed share of group %2$s" : "Freigabe für Gruppe %2$s entfernt",
    "%2$s removed share of group %3$s" : "%2$s hat die Freigabe für Gruppe %3$s entfernt",
    "Shared via link by %2$s" : "Geteilt durch einen Link von %2$s",
    "Shared via public link" : "Durch einen öffentlichen Link geteilt",
    "Removed public link" : "Öffentlichen Link entfernt",
    "%2$s removed public link" : "%2$s hat die Freigabe als Link entfernt",
    "Public link expired" : "öffentlicher Link ist abgelaufen",
    "Public link of %2$s expired" : "Öffentlicher Link von %2$s ist abgelaufen",
    "Shared by %2$s" : "Geteilt von %2$s",
    "Shares" : "Geteiltes",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Freigabezeitpunkt",
    "Expiration date" : "Ablaufdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "%s is publicly shared" : "%s wird öffentlich geteilt",
    "Add to your ownCloud" : "Zu Ihrer ownCloud hinzufügen",
    "Download" : "Herunterladen",
    "Download %s" : "Download %s",
    "Direct link" : "Direkte Verlinkung"
},
"nplurals=2; plural=(n != 1);");
